#ifndef DEVICECONFIGURATOR_H_INCLUDED
#define DEVICECONFIGURATOR_H_INCLUDED

#include "StdAfx.h"

enum DeviceConfiguratorStatus
{
    /**
    OK.
    */
    DEVICE_CONFIGURATOR_OK, 
    
    /** 
    Failed.
    */
    DEVICE_CONFIGURATOR_FAILED,

	/** 
    Invalid license.
    */
    DEVICE_CONFIGURATOR_INVALID_LICENSE,

	/** 
    Device configurator hasn't enough resources.
    */
    DEVICE_CONFIGURATOR_NO_RESOURCES,

	/** 
    Device configurator hasn't such client.
    */
    DEVICE_CONFIGURATOR_NO_SUCH_CLIENT,

	/** 
    References file is missing.
    */
	DEVICE_CONFIGURATOR_NO_INFORMATION_FILE,

	/** 
    History file is missing.
    */
	DEVICE_CONFIGURATOR_NO_HISTORY_FILE,

	/** 
    License file is missing.
    */
	DEVICE_CONFIGURATOR_NO_LICENSE_FILE,

	/** 
    Unknown error. 
    */
    DEVICE_CONFIGURATOR_UNKNOWN_ERROR
};

struct DeviceInfo
{
	int deviceId;
	int vendorId;
};

struct LicenseInfo
{
	int deviceId;
	int license;
};

struct ConfigurationCommand
{
	int commandId;
	char* data;
	int dataLength;
};


extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_RegisterClient( DeviceInfo deviceInfo );

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_UnregisterClient( DeviceInfo deviceInfo );

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_CheckLicense( DeviceInfo deviceInfo, LicenseInfo licenseInfo );

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_ConfigureDevice( DeviceInfo deviceInfo, LicenseInfo licenseInfo,
										ConfigurationCommand*& commands, int& commandsCount );

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_FreeCommandData( ConfigurationCommand* commands, 
												const int commandsCount );


#endif