#include "StdAfx.h"
#include "ClientManager.h"

const string LICENSE_FILE_PATH_DEFAULT = 
	"../../../../../MasterThesis/DeviceConfigurator/res/licenses.dat";

const string LICENSE_FILE_LINE_SEPARATOR = ";";


ClientManager::ClientManager()
{
	m_strLicenseFilePath = LICENSE_FILE_PATH_DEFAULT;
}

ClientManager::ClientManager( const string licenseFilePath )
{
	m_strLicenseFilePath = licenseFilePath;
}

DeviceConfiguratorStatus ClientManager::CheckLicense( 
						DeviceInfo deviceInfo, LicenseInfo licenseInfo )
{
	const int BUFFER_MAX_SIZE = 256;
	ifstream licenseFileIfstream;
	licenseFileIfstream.open( m_strLicenseFilePath.c_str() );
	if ( !licenseFileIfstream.is_open() )
	{
		return DEVICE_CONFIGURATOR_NO_LICENSE_FILE;
	}
	
	char currentLine[BUFFER_MAX_SIZE];
	DeviceConfiguratorStatus currentResult = DEVICE_CONFIGURATOR_OK;
	bool licenseOK = false;

	while( !licenseFileIfstream.eof() && !licenseOK 
			&& currentResult == DEVICE_CONFIGURATOR_OK )
	{
		licenseFileIfstream.getline( currentLine, BUFFER_MAX_SIZE );
		vector<string> lineElements;
		currentResult = splitLine( currentLine, lineElements );
		
		if ( currentResult == DEVICE_CONFIGURATOR_OK 
			&& matchLicense( lineElements, licenseInfo ) )
		{
			licenseOK = true;
		}
	}

	licenseFileIfstream.close();

	if ( licenseOK )
	{
		return DEVICE_CONFIGURATOR_OK;
	}
	return DEVICE_CONFIGURATOR_INVALID_LICENSE;
}

DeviceConfiguratorStatus ClientManager::splitLine( const string& line, 
													vector<string>& lineElements )
{
	unsigned int startPos = 0;
	unsigned int nextSeparatorPos = 0;
	while ( startPos < line.length() && nextSeparatorPos != string::npos ) 
	{
		nextSeparatorPos = line.find( LICENSE_FILE_LINE_SEPARATOR, startPos );
		if ( nextSeparatorPos != string::npos )
		{		
			string strElement ( line, startPos, nextSeparatorPos - startPos ); 
			lineElements.push_back( strElement );
			startPos = nextSeparatorPos + 1;
		}
		else
		{
			// add last element
			string strElement ( line, startPos, line.length() - startPos ); 
			lineElements.push_back( strElement );
		}
	}
	return DEVICE_CONFIGURATOR_OK;
}

bool ClientManager::matchLicense( const vector<string>& lineElements, 
								 const LicenseInfo& licenseInfo )
{
	const unsigned int lineElementsSize = 2;
	const int licensePositionInLineElements = 0;
	const int devicePositionInLineElements = 1;
	
	if ( lineElements.size() != lineElementsSize )
	{
		return false;
	}
	
	int license = atoi( lineElements.at( licensePositionInLineElements ).c_str() );
	int deviceId = atoi( lineElements.at( devicePositionInLineElements ).c_str() );	

	if ( deviceId == licenseInfo.deviceId
		&& license == licenseInfo.license )
	{
		return true;
	}
	return false;
}

