#include "StdAfx.h"
#include "ConfigurationFileProcessor.h"

ConfigurationFileProcessor::ConfigurationFileProcessor()
{
	m_strConfigurationFilePath = "";
}

ConfigurationFileProcessor::ConfigurationFileProcessor( const string& configurationFilePath )
{
	m_strConfigurationFilePath = configurationFilePath;
}

DeviceConfiguratorStatus 
ConfigurationFileProcessor::ProcessConfigurationFile( ConfigurationCommand*& commands, 
																	int& commandsCount )
{
	const int BUFFER_MAX_SIZE = 256;
	const int COMMAND_ID_LENGTH = 4;

	ifstream cfgFileIfstream;
	
	cfgFileIfstream.open( m_strConfigurationFilePath.c_str() );
	if ( !cfgFileIfstream.is_open() )
	{
		return DEVICE_CONFIGURATOR_FAILED;
	}

	char currentLine[BUFFER_MAX_SIZE];
	int linesCount = 0;
	while( !cfgFileIfstream.eof() )
	{
		cfgFileIfstream.getline( currentLine, BUFFER_MAX_SIZE );
		linesCount++;
	}
	
	cfgFileIfstream.close();
	if ( linesCount <= 0 )
	{
		return DEVICE_CONFIGURATOR_FAILED;
	}

	commands = new ConfigurationCommand[linesCount];
	if ( commands == NULL )
	{
		return DEVICE_CONFIGURATOR_FAILED;
	}

	memset( commands, 0, linesCount*sizeof(ConfigurationCommand) );
	commandsCount = linesCount;

	// clear the stream, it will be linked to a file
	cfgFileIfstream.clear();
	cfgFileIfstream.open( m_strConfigurationFilePath.c_str() );
		
	

	int i = 0;
	while( !cfgFileIfstream.eof() )
	{
		cfgFileIfstream.getline( currentLine, BUFFER_MAX_SIZE );
		if ( strlen(currentLine) > COMMAND_ID_LENGTH )
		{
			string strLine( currentLine );

			string strCommandId = strLine.substr( 0, COMMAND_ID_LENGTH ); 
			int commandId = atoi( strCommandId.c_str() );
			
			strLine = strLine.substr( COMMAND_ID_LENGTH );
			
			commands[i].commandId = commandId;
			commands[i].data = new char[strLine.length() + 1];
			if ( commands[i].data != NULL )
			{			
				memset( commands[i].data, 0, strLine.length() + 1 );
				memcpy( commands[i].data, strLine.c_str(), strLine.length() + 1 );
				commands[i].dataLength = strLine.length() + 1;
			}						

			i++;
		}
	}

	cfgFileIfstream.close();

	return DEVICE_CONFIGURATOR_OK;
}

string ConfigurationFileProcessor::GetConfigurationFilePath() const
{
	return m_strConfigurationFilePath;
}

void ConfigurationFileProcessor::SetConfigurationFilePath( 
							const string& configurationFilePath )
{
	m_strConfigurationFilePath = configurationFilePath;
}