#include "StdAfx.h"

#include "DeviceConfigurator.h"
#include "ClientManager.h"
#include "ConfiguratorService.h"


const int MAX_CLIENTS_COUNT = 10;

vector<DeviceInfo> G_RegisteredClients = vector<DeviceInfo>();

bool dc_isClient( DeviceInfo deviceInfo );


extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_RegisterClient( DeviceInfo deviceInfo )
{
	if ( G_RegisteredClients.size() >= MAX_CLIENTS_COUNT )
	{
		return DEVICE_CONFIGURATOR_NO_RESOURCES;
	}

	if ( !dc_isClient( deviceInfo ) )
	{
		// add this client
		G_RegisteredClients.push_back( deviceInfo );		
	}
	else
	{
		// this client is already registered
	}
	return DEVICE_CONFIGURATOR_OK;
}

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_UnregisterClient( DeviceInfo deviceInfo )
{
	bool found = false;
	for ( int i = 0; i < G_RegisteredClients.size() && !found; i++ )
	{
		DeviceInfo currentDeviceInfo = G_RegisteredClients.at( i );
		if ( currentDeviceInfo.deviceId == deviceInfo.deviceId
			&& currentDeviceInfo.vendorId == deviceInfo.vendorId )
		{
			// remove this client
			G_RegisteredClients.erase( G_RegisteredClients.begin() + i );

			found = true;
		}
	}

	if ( found )
	{
		return DEVICE_CONFIGURATOR_OK;
	}
	else
	{
		return DEVICE_CONFIGURATOR_NO_SUCH_CLIENT;
	}
}

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_CheckLicense( DeviceInfo deviceInfo, LicenseInfo licenseInfo )
{
	if ( !dc_isClient( deviceInfo ) )
	{
		return DEVICE_CONFIGURATOR_NO_SUCH_CLIENT;
	}
	ClientManager clientManager;
	DeviceConfiguratorStatus status = clientManager.CheckLicense( deviceInfo, licenseInfo );
	return status;
}

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_ConfigureDevice( DeviceInfo deviceInfo, LicenseInfo licenseInfo,
										ConfigurationCommand*& commands, int& commandsCount )
{
	if ( !dc_isClient( deviceInfo ) )
	{
		return DEVICE_CONFIGURATOR_NO_SUCH_CLIENT;
	}
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	// check license
	ClientManager clientManager;
	status = clientManager.CheckLicense( deviceInfo, licenseInfo );
	if ( status != DEVICE_CONFIGURATOR_OK )
	{
		return status;
	}

	ConfiguratorService configuratorService;
	status = configuratorService.GetConfigurationCommands( deviceInfo, licenseInfo,
															commands, commandsCount );
	
	return status;
}

extern "C" __declspec(dllexport) 
DeviceConfiguratorStatus DC_FreeCommandData( ConfigurationCommand* commands, 
												const int commandsCount )
{
	if ( commands == NULL || commandsCount <= 0 )
	{
		return DEVICE_CONFIGURATOR_FAILED;
	}

	for ( int i = 0; i < commandsCount; i++ )
	{
		ConfigurationCommand* configurationCommand = commands + i;
		if ( configurationCommand != NULL )
		{
			if ( configurationCommand -> data != NULL )
			{
				delete configurationCommand -> data;
				configurationCommand -> data = NULL;
			}			
		}
	}
	delete commands;

	return DEVICE_CONFIGURATOR_OK;
}

bool dc_isClient( DeviceInfo deviceInfo )
{
	for ( int i = 0; i < G_RegisteredClients.size(); i++ )
	{
		DeviceInfo currentDeviceInfo = G_RegisteredClients.at( i );
		if ( currentDeviceInfo.deviceId == deviceInfo.deviceId
			&& currentDeviceInfo.vendorId == deviceInfo.vendorId )
		{
			return true;
		}
	}
	return false;
}