#ifndef CPP_UNIT_DEVICECONFIGURATORTESTCASE_H
#define CPP_UNIT_DEVICECONFIGURATORTESTCASE_H

#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

// tested object
#include "DeviceConfigurator.h"

/*
This is a tester class for DeviceConfigurator.
*/
class DeviceConfiguratorTestCase : public CppUnit::TestCase
{
	CU_TEST_SUITE( DeviceConfiguratorTestCase );

	CU_TEST( testRegisterClient );

	CU_TEST( testUnregisterClient );
	CU_TEST( testUnregisterClient_fail_noSuchClient );

	CU_TEST( testCheckLicense );
	CU_TEST( testCheckLicense_fail_noSuchClient );
	CU_TEST( testCheckLicense_fail_invalidLicense );

	CU_TEST( testConfigureDevice );
	CU_TEST( testConfigureDevice_noSuchClient );
	CU_TEST( testConfigureDevice_invalidLicense );

	CU_TEST( testFreeCommandData );
	CU_TEST( testFreeCommandData_fail );

	CU_TEST_SUITE_END();

public:

	void setUp();
	void tearDown();

protected:

	void testRegisterClient();

	void testUnregisterClient();
	void testUnregisterClient_fail_noSuchClient();

	void testCheckLicense();
	void testCheckLicense_fail_noSuchClient();
	void testCheckLicense_fail_invalidLicense();

	void testConfigureDevice();
	void testConfigureDevice_noSuchClient();
	void testConfigureDevice_invalidLicense();

	void testFreeCommandData();
	void testFreeCommandData_fail();

private:

	bool checkConfigurationCommands( const ConfigurationCommand* commands,
										const int commandsCount );

	DeviceInfo m_DeviceInfo;

	LicenseInfo m_LicenseInfo;
};


#endif