#include "stdafx.h"

#include <cppunit/extensions/TestSuiteBuilder.h>
#include "ClientManagerTestCase.h"
#include "TestIncludes.h"


CU_TEST_SUITE_REGISTRATION( ClientManagerTestCase );


void ClientManagerTestCase::setUp()
{
	m_DeviceInfo.deviceId = DEVICE_ID_DEFAULT;
	m_DeviceInfo.vendorId = VENDOR_ID_DEFAULT;
	m_LicenseInfo.deviceId = DEVICE_ID_DEFAULT;
	m_LicenseInfo.license = LICENSE_DEFAULT;
}

void ClientManagerTestCase::tearDown()
{
}

void ClientManagerTestCase::testCheckLicense()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;
	ClientManager clientManager;

	status = clientManager.CheckLicense( m_DeviceInfo, m_LicenseInfo );	
	assert( status == DEVICE_CONFIGURATOR_OK );	
}

void ClientManagerTestCase::testCheckLicense_fail_invalidLicense()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;
	ClientManager clientManager;
	
	// set an invalid license and test
	m_LicenseInfo.license = INVALID_LICENSE_DEFAULT;
	status = clientManager.CheckLicense( m_DeviceInfo, m_LicenseInfo );	
	assert( status == DEVICE_CONFIGURATOR_INVALID_LICENSE );	
}

void ClientManagerTestCase::testCheckLicense_fail_noLicenseFile()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;
	ClientManager clientManager( "invalidPath" );
	
	status = clientManager.CheckLicense( m_DeviceInfo, m_LicenseInfo );	
	assert( status == DEVICE_CONFIGURATOR_NO_LICENSE_FILE );	
}

void ClientManagerTestCase::testSplitLine()
{
	const string line = "12;23;34;45;56;67;78;89;90";
	const string element1 = "12";
	const string element2 = "23";
	const string element3 = "34";
	const string element4 = "45";
	const string element5 = "56";
	const string element6 = "67";
	const string element7 = "78";
	const string element8 = "89";
	const string element9 = "90";
	
	vector<string> lineElements;
	
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;
	ClientManager clientManager;
	status = clientManager.splitLine( line, lineElements );	
	
	assert( status == DEVICE_CONFIGURATOR_OK );

	assert( 0 == element1.compare( lineElements.at(0) ));
	assert( 0 == element2.compare( lineElements.at(1) ));
	assert( 0 == element3.compare( lineElements.at(2) ));
	assert( 0 == element4.compare( lineElements.at(3) ));
	assert( 0 == element5.compare( lineElements.at(4) ));
	assert( 0 == element6.compare( lineElements.at(5) ));
	assert( 0 == element7.compare( lineElements.at(6) ));
	assert( 0 == element8.compare( lineElements.at(7) ));
	assert( 0 == element9.compare( lineElements.at(8) ));
}

void ClientManagerTestCase::testSplitLine_emptyElements()
{
	// set some empty elements between delimiters
	const string line = "12;23;;;;67;78;;90";
	const string element1 = "12";
	const string element2 = "23";
	const string element3 = "";
	const string element4 = "";
	const string element5 = "";
	const string element6 = "67";
	const string element7 = "78";
	const string element8 = "";
	const string element9 = "90";
	
	vector<string> lineElements;
	
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;
	ClientManager clientManager;
	status = clientManager.splitLine( line, lineElements );	
	
	assert( status == DEVICE_CONFIGURATOR_OK );

	assert( 0 == element1.compare( lineElements.at(0) ));
	assert( 0 == element2.compare( lineElements.at(1) ));
	assert( 0 == element3.compare( lineElements.at(2) ));
	assert( 0 == element4.compare( lineElements.at(3) ));
	assert( 0 == element5.compare( lineElements.at(4) ));
	assert( 0 == element6.compare( lineElements.at(5) ));
	assert( 0 == element7.compare( lineElements.at(6) ));
	assert( 0 == element8.compare( lineElements.at(7) ));
	assert( 0 == element9.compare( lineElements.at(8) ));
}

void ClientManagerTestCase::testMatchLicense()
{
	const string line = "281;1234";
	
	vector<string> lineElements;
	lineElements.push_back( "281" );
	lineElements.push_back( "1234" );
	
	ClientManager clientManager;
	assert( clientManager.matchLicense( lineElements, m_LicenseInfo ) );
}

void ClientManagerTestCase::testMatchLicense_fail_invalidLicense()
{
	const string line = "281;1234";
	
	vector<string> lineElements;
	lineElements.push_back( "281" );
	lineElements.push_back( "1234" );
	
	// set an invalid license and test
	m_LicenseInfo.license = INVALID_LICENSE_DEFAULT;
	
	ClientManager clientManager;

	assert( ! clientManager.matchLicense( lineElements, m_LicenseInfo ) );
}


