#include "stdafx.h"

#include <cppunit/extensions/TestSuiteBuilder.h>
#include "ConfigurationFileProcessorTestCase.h"
#include "TestIncludes.h"


CU_TEST_SUITE_REGISTRATION( ConfigurationFileProcessorTestCase );



void ConfigurationFileProcessorTestCase::setUp()
{
	m_strConfigurationFilePath = "";
}

void ConfigurationFileProcessorTestCase::tearDown()
{
}

void ConfigurationFileProcessorTestCase::testGetConfigurationFilePath()
{
	ConfigurationFileProcessor configurationFileProcessor;
	configurationFileProcessor.m_strConfigurationFilePath = TEST_CONFIGURATION_FILE_PATH;
	
	string testString = configurationFileProcessor.GetConfigurationFilePath();

	assert( testString.compare( TEST_CONFIGURATION_FILE_PATH ) == 0 );
}

void ConfigurationFileProcessorTestCase::testSetConfigurationFilePath()
{
	ConfigurationFileProcessor configurationFileProcessor;
	configurationFileProcessor.SetConfigurationFilePath( TEST_CONFIGURATION_FILE_PATH );
	
	string testString = configurationFileProcessor.m_strConfigurationFilePath;

	assert( testString.compare( TEST_CONFIGURATION_FILE_PATH ) == 0 );
}

void ConfigurationFileProcessorTestCase::testProcessConfigurationFile()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationFileProcessor configurationFileProcessor( TEST_CONFIGURATION_FILE_PATH );

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	status = configurationFileProcessor.ProcessConfigurationFile(
							pConfigurationCommands, configurationCommandsCount );

	assert( status == DEVICE_CONFIGURATOR_OK );
	assert( pConfigurationCommands != NULL );
	assert( configurationCommandsCount > 0 );


	// clean up the data
	for ( int i = 0; i < configurationCommandsCount; i++ )
	{
		ConfigurationCommand* configurationCommand = pConfigurationCommands + i;
		if ( configurationCommand != NULL )
		{
			if ( configurationCommand -> data != NULL )
			{
				delete configurationCommand -> data;
				configurationCommand -> data = NULL;
			}			
		}
	}
	delete pConfigurationCommands;
}

void ConfigurationFileProcessorTestCase::testProcessConfigurationFile_fail_noFile()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationFileProcessor configurationFileProcessor( 
								TEST_CONFIGURATION_FILE_PATH_INVALID );

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	status = configurationFileProcessor.ProcessConfigurationFile(
							pConfigurationCommands, configurationCommandsCount );

	assert( status != DEVICE_CONFIGURATOR_OK );
	assert( pConfigurationCommands == NULL );
	assert( configurationCommandsCount == 0 );
}