#include "stdafx.h"

#include <cppunit/extensions/TestSuiteBuilder.h>
#include "ConfiguratorServiceTestCase.h"
#include "TestIncludes.h"


CU_TEST_SUITE_REGISTRATION( ConfiguratorServiceTestCase );


void ConfiguratorServiceTestCase::setUp()
{
	m_DeviceInfo.deviceId = DEVICE_ID_DEFAULT;
	m_DeviceInfo.vendorId = VENDOR_ID_DEFAULT;
	m_LicenseInfo.deviceId = DEVICE_ID_DEFAULT;
	m_LicenseInfo.license = LICENSE_DEFAULT;
}

void ConfiguratorServiceTestCase::tearDown()
{
}

void ConfiguratorServiceTestCase::testGetConfigurationCommands()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	ConfiguratorService configuratorService;
	status = configuratorService.GetConfigurationCommands( 
							m_DeviceInfo, m_LicenseInfo,
							pConfigurationCommands, configurationCommandsCount );

	assert( status == DEVICE_CONFIGURATOR_OK );
	assert( pConfigurationCommands != NULL );
	assert( configurationCommandsCount > 0 );


	// clean up the data
	for ( int i = 0; i < configurationCommandsCount; i++ )
	{
		ConfigurationCommand* configurationCommand = pConfigurationCommands + i;
		if ( configurationCommand != NULL )
		{
			if ( configurationCommand -> data != NULL )
			{
				delete configurationCommand -> data;
				configurationCommand -> data = NULL;
			}			
		}
	}
	delete pConfigurationCommands;	
}

void ConfiguratorServiceTestCase::testGetConfigurationCommands_fail_noReference()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	// set vendorId to unsupported vendor
	m_DeviceInfo.vendorId = UNSUPPORTED_VENDOR_ID;

	ConfiguratorService configuratorService;
	status = configuratorService.GetConfigurationCommands( 
							m_DeviceInfo, m_LicenseInfo,
							pConfigurationCommands, configurationCommandsCount );

	assert( status != DEVICE_CONFIGURATOR_INVALID_LICENSE );
	assert( pConfigurationCommands == NULL );
	assert( configurationCommandsCount == 0 );
}

void ConfiguratorServiceTestCase::testGetConfigurationCommands_fail_noFile()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	// set vendorId to unsupported vendor
	m_DeviceInfo.vendorId = UNSUPPORTED_VENDOR_ID;

	ConfiguratorService configuratorService;
	status = configuratorService.GetConfigurationCommands( 
							m_DeviceInfo, m_LicenseInfo,
							pConfigurationCommands, configurationCommandsCount );

	assert( status != DEVICE_CONFIGURATOR_OK );
	assert( pConfigurationCommands == NULL );
	assert( configurationCommandsCount == 0 );
}

void ConfiguratorServiceTestCase::testProcessConfigurationFile()
{

	const string CFG_DATA_EXPECTED = "TestCommandData1";

	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	ConfiguratorService configuratorService;
	status = configuratorService.processConfigurationFile( TEST_CONFIGURATION_FILE_PATH, 
															pConfigurationCommands, 
															configurationCommandsCount ); 
	assert( status == DEVICE_CONFIGURATOR_OK );
	assert( configurationCommandsCount == 1 );	
	assert( pConfigurationCommands[0].commandId  == 1 );

	string cfgData = string( pConfigurationCommands[0].data );
	assert( cfgData.compare( CFG_DATA_EXPECTED )  == 0 );
}

void ConfiguratorServiceTestCase::testProcessConfigurationFile_fail_noFile()
{
	DeviceConfiguratorStatus status = DEVICE_CONFIGURATOR_UNKNOWN_ERROR;

	ConfigurationCommand* pConfigurationCommands = NULL;
	int configurationCommandsCount = 0;

	ConfiguratorService configuratorService;
	status = configuratorService.processConfigurationFile( TEST_CONFIGURATION_FILE_PATH_INVALID, 
															pConfigurationCommands, 
															configurationCommandsCount ); 
	assert( status != DEVICE_CONFIGURATOR_OK );
	assert( configurationCommandsCount == 0 );	
	assert( pConfigurationCommands == NULL );
}